@@ -18,9 +18,12 @@ export LANG=C.UTF-8
 # Avoid systemd trying to color the terminal on systemd-nspawn
 export SYSTEMD_TINT_BACKGROUND=no
 
+# Avoid diffoscope looking at remote debug info through readelf
+unset DEBUGINFOD_URLS
+
 # Set buildtool properties
 export BUILDTOOL=${BUILDTOOL:-devtools-archlinuxcn}
-export BUILDTOOLVER=1:1.3.0-1-any
+export BUILDTOOLVER=1:1.5.0-1-any
 
 # Set common properties
 export PACMAN_KEYRING_DIR=/etc/pacman.d/gnupg
@@ -51,7 +54,8 @@ export RSYNC_OPTS=(
   --human-readable
   --progress
   --partial
-  --partial-dir=.partial
+  # suffix the partial dir with the PID in order to avoid clashes
+  --partial-dir=.partial.$$
   --delay-updates
 )
 
@@ -438,3 +442,10 @@ relative_date_unit() {
 	done
 	printf "1 second"
 }
+
+
+# escapes regex metacharacters in a given string
+regex_escape() {
+	# shellcheck disable=SC2001,SC2016
+	sed 's/[\^.\[$()|*+?{\\]/\\&/g' <<<"$1"
+}
